@@ -718,6 +718,8 @@ pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
 // sa, Saudi Arabia, .<al-Saudiah>
 pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
 // ru, Russian Federation, .<RF>
@@ -811,7 +813,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 826 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 828 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -830,9 +832,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 846 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 848 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 853 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 855 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1194,15 +1196,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1593 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 1595 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2010 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2012 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2211 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2213 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2305 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2307 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2308 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2310 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1470,20 +1472,20 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2578 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2580 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2646 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2648 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2672 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
-
-//@line 2692 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2674 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 //@line 2694 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
+//@line 2696 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2700 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2702 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1507,7 +1509,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2729 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
+//@line 2731 "/export/home/moz/tools/ff_slave/mozilla-1.9.1-solaris-sparc-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
